<?php
/**
 * The main export/import class.
 *
 * @since 2.0.0
 */
final class Neovantage_Customize_Export_Import {

	/**
	 * An array of core options that shouldn't be imported.
	 *
	 * @since 2.0.0
	 * @access private
	 * @var array $core_options
	 */
	private static $core_options = array(
		'blogname',
		'blogdescription',
		'show_on_front',
		'page_on_front',
		'page_for_posts',
	);

	/**
	 * Check to see if we need to do an export or import.
	 * This should be called by the customize_register action.
	 *
	 * @since 2.0.0
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 *
	 * @return void
	 */
	public static function init( $wp_customize ) {

		if ( current_user_can( 'edit_theme_options' ) ) {

			if ( isset( $_REQUEST['nei-export'] ) ) {
				self::_export( $wp_customize );
			}

			if ( isset( $_REQUEST['nei-import'] ) && isset( $_FILES['nei-import-file'] ) ) {
				self::_import( $wp_customize );
			}
		}
	}

	/**
	 * Prints scripts for the control.
	 *
	 * @since 2.0.0
	 * @return void
	 */
	public static function controls_print_scripts() {
		global $nei_error;

		if ( $nei_error ) {
			echo '<script> alert("' . $nei_error . '"); </script>';
		}
	}

	/**
	 * Export customizer settings.
	 *
	 * @since 2.0.0
	 * @access private
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 *
	 * @return void
	 */
	private static function _export( $wp_customize ) {
		if ( ! wp_verify_nonce( $_REQUEST['nei-export'], 'nei-exporting' ) ) {
			return;
		}

		$theme    = get_stylesheet();
		$template = get_template();
		$charset  = get_option( 'blog_charset' );
		$mods     = get_theme_mods();
		$data     = array(
			'template' => $template,
			'mods'     => $mods ? $mods : array(),
			'options'  => array(),
		);

		// Get options from the Customizer API.
		$settings = $wp_customize->settings();

		foreach ( $settings as $key => $setting ) {

			if ( 'option' == $setting->type ) {

				// Don't save widget data.
				if ( 'widget_' === substr( strtolower( $key ), 0, 7 ) ) {
					continue;
				}

				// Don't save sidebar data.
				if ( 'sidebars_' === substr( strtolower( $key ), 0, 9 ) ) {
					continue;
				}

				// Don't save core options.
				if ( in_array( $key, self::$core_options ) ) {
					continue;
				}

				$data['options'][ $key ] = $setting->value();
			}
		}

		// Plugin developers can specify additional option keys to export.
		$option_keys = apply_filters( 'nei_export_option_keys', array() );

		foreach ( $option_keys as $option_key ) {
			$data['options'][ $option_key ] = get_option( $option_key );
		}

		if ( function_exists( 'wp_get_custom_css_post' ) ) {
			$data['wp_css'] = wp_get_custom_css();
		}

		// Set the download headers.
		nocache_headers();
		// header( 'Content-Disposition: attachment; filename=' . $theme . '-theme-options.json' );
		// header( 'Content-Type: application/json; charset=' . $charset );
		header( 'Content-Disposition: attachment; filename=' . $theme . '-theme-options.dat' );
		header( 'Content-Type: application/octet-stream; charset=' . $charset );

		header( 'Expires: 0' );

		// Serialize the export data.
		echo serialize( $data );

		// Encode the export data in JSON format.
		// echo wp_json_encode( $data );

		// Start the download.
		die();
	}

	/**
	 * Imports uploaded mods and calls WordPress core customize_save actions so
	 * themes that hook into them can act before mods are saved to the database.
	 *
	 * @since 2.0.0
	 *
	 * @access private
	 *
	 * @param object $wp_customize An instance of WP_Customize_Manager.
	 *
	 * @return void
	 */
	private static function _import( $wp_customize ) {
		// Make sure we have a valid nonce.
		if ( ! wp_verify_nonce( $_REQUEST['nei-import'], 'nei-importing' ) ) {
			return;
		}

		// Make sure WordPress upload support is loaded.
		if ( ! function_exists( 'wp_handle_upload' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}

		// Load the export/import option class.
		require_once get_template_directory() . '/inc/customizer/class-neovantage-customize-export-import-option.php';

		// Setup global vars.
		global $wp_customize;
		global $nei_error;

		// Setup internal vars.
		$nei_error = false;
		$template  = get_template();
		$overrides = array(
			'test_form' => false,
			'test_type' => false,
			'mimes'     => array( 'dat' => 'text/plain' ),
		);

		$file = wp_handle_upload( $_FILES['nei-import-file'], $overrides );

		// Make sure we have an uploaded file.
		if ( isset( $file['error'] ) ) {
			$nei_error = $file['error'];
			return;
		}

		if ( ! file_exists( $file['file'] ) ) {
			$nei_error = __( 'Error importing settings! Please try again.', 'neovantage' );
			return;
		}

		// Initialize the filesystem.
		$wp_filesystem = self::init_filesystem();

		// Get the upload data.
		// $raw  = file_get_contents( $file['file'] );
		$raw  = $wp_filesystem->get_contents( $file['file'] );
		$data = @unserialize( $raw );

		// Remove the uploaded file.
		unlink( $file['file'] );

		// Data checks.
		if ( 'array' != gettype( $data ) ) {
			$nei_error = __( 'Error importing settings! Please check that you uploaded a customizer export file.', 'neovantage' );
			return;
		}
		if ( ! isset( $data['template'] ) || ! isset( $data['mods'] ) ) {
			$nei_error = __( 'Error importing settings! Please check that you uploaded a customizer export file.', 'neovantage' );
			return;
		}
		if ( $data['template'] != $template ) {
			$nei_error = __( 'Error importing settings! The settings you uploaded are not for the current theme.', 'neovantage' );
			return;
		}

		// Import images.
		if ( isset( $_REQUEST['nei-import-images'] ) ) {
			$data['mods'] = self::_import_images( $data['mods'] );
		}

		// Import custom options.
		if ( isset( $data['options'] ) ) {

			foreach ( $data['options'] as $option_key => $option_value ) {

				$option = new Neovantage_Customize_Export_Import_Option(
					$wp_customize,
					$option_key,
					array(
						'default'    => '',
						'type'       => 'option',
						'capability' => 'edit_theme_options',
					)
				);

				$option->import( $option_value );
			}
		}

		// If wp_css is set then import it.
		if ( function_exists( 'wp_update_custom_css_post' ) && isset( $data['wp_css'] ) && '' !== $data['wp_css'] ) {
			wp_update_custom_css_post( $data['wp_css'] );
		}

		// Call the customize_save action.
		do_action( 'customize_save', $wp_customize );

		// Loop through the mods.
		foreach ( $data['mods'] as $key => $val ) {

			// Call the customize_save_ dynamic action.
			do_action( 'customize_save_' . $key, $wp_customize );

			// Save the mod.
			set_theme_mod( $key, $val );
		}

		// Call the customize_save_after action.
		do_action( 'customize_save_after', $wp_customize );
	}

	/**
	 * Imports images for settings saved as mods.
	 *
	 * @since 2.0.0
	 * @access private
	 * @param array $mods An array of customizer mods.
	 *
	 * @return array The mods array with any new import data.
	 */
	private static function _import_images( $mods ) {
		foreach ( $mods as $key => $val ) {

			if ( self::_is_image_url( $val ) ) {

				$data = self::_sideload_image( $val );

				if ( ! is_wp_error( $data ) ) {

					$mods[ $key ] = $data->url;

					// Handle header image controls.
					if ( isset( $mods[ $key . '_data' ] ) ) {
						$mods[ $key . '_data' ] = $data;
						update_post_meta( $data->attachment_id, '_wp_attachment_is_custom_header', get_stylesheet() );
					}
				}
			}
		}

		return $mods;
	}

	/**
	 * Taken from the core media_sideload_image function and
	 * modified to return an array of data instead of HTML.
	 *
	 * @since 2.0.0
	 * @access private
	 * @param string $file The image file path.
	 *
	 * @return array An array of image data.
	 */
	private static function _sideload_image( $file ) {
		$data = new stdClass();

		if ( ! function_exists( 'media_handle_sideload' ) ) {
			require_once ABSPATH . 'wp-admin/includes/media.php';
			require_once ABSPATH . 'wp-admin/includes/file.php';
			require_once ABSPATH . 'wp-admin/includes/image.php';
		}

		if ( ! empty( $file ) ) {

			// Set variables for storage, fix file filename for query strings.
			preg_match( '/[^\?]+\.(jpe?g|jpe|gif|png)\b/i', $file, $matches );
			$file_array         = array();
			$file_array['name'] = basename( $matches[0] );

			// Download file to temp location.
			$file_array['tmp_name'] = download_url( $file );

			// If error storing temporarily, return the error.
			if ( is_wp_error( $file_array['tmp_name'] ) ) {
				return $file_array['tmp_name'];
			}

			// Do the validation and storage stuff.
			$id = media_handle_sideload( $file_array, 0 );

			// If error storing permanently, unlink.
			if ( is_wp_error( $id ) ) {
				@unlink( $file_array['tmp_name'] );
				return $id;
			}

			// Build the object to return.
			$meta                = wp_get_attachment_metadata( $id );
			$data->attachment_id = $id;
			$data->url           = wp_get_attachment_url( $id );
			$data->thumbnail_url = wp_get_attachment_thumb_url( $id );
			$data->height        = $meta['height'];
			$data->width         = $meta['width'];
		}

		return $data;
	}

	/**
	 * Checks to see whether a string is an image URL or not.
	 *
	 * @since 2.0.0
	 * @access private
	 * @param string $string The string to check.
	 *
	 * @return bool Whether the string is an image URL or not.
	 */
	private static function _is_image_url( $string = '' ) {
		if ( is_string( $string ) ) {

			if ( preg_match( '/\.(jpg|jpeg|png|gif)/i', $string ) ) {
				return true;
			}
		}

		return false;
	}

	/**
	 * Instantiates the WordPress filesystem.
	 *
	 * @static
	 * @access public
	 * @return object WP_Filesystem
	 */
	public static function init_filesystem() {

		$credentials = array();

		if ( ! defined( 'FS_METHOD' ) ) {
			define( 'FS_METHOD', 'direct' );
		}

		$method = defined( 'FS_METHOD' ) ? FS_METHOD : false;

		if ( 'ftpext' === $method ) {
			// If defined, set it to that, Else, set to NULL.
			$credentials['hostname'] = defined( 'FTP_HOST' ) ? preg_replace( '|\w+://|', '', FTP_HOST ) : null;
			$credentials['username'] = defined( 'FTP_USER' ) ? FTP_USER : null;
			$credentials['password'] = defined( 'FTP_PASS' ) ? FTP_PASS : null;

			// Set FTP port.
			if ( strpos( $credentials['hostname'], ':' ) && null !== $credentials['hostname'] ) {
				list( $credentials['hostname'], $credentials['port'] ) = explode( ':', $credentials['hostname'], 2 );
				if ( ! is_numeric( $credentials['port'] ) ) {
					unset( $credentials['port'] );
				}
			} else {
				unset( $credentials['port'] );
			}

			// Set connection type.
			if ( ( defined( 'FTP_SSL' ) && FTP_SSL ) && 'ftpext' === $method ) {
				$credentials['connection_type'] = 'ftps';
			} elseif ( ! array_filter( $credentials ) ) {
				$credentials['connection_type'] = null;
			} else {
				$credentials['connection_type'] = 'ftp';
			}
		}

		// The WordPress filesystem.
		global $wp_filesystem;

		if ( empty( $wp_filesystem ) ) {
			require_once wp_normalize_path( ABSPATH . '/wp-admin/includes/file.php' );
			WP_Filesystem( $credentials );
		}

		return $wp_filesystem;
	}
}
