<?php
/**
 * Customizer: Sanitization Callbacks
 *
 * This file defines sanitization callback functions for various data types
 * referred to in the Customizer.
 *
 * @see https://github.com/WPTRT/code-examples/blob/master/customizer/sanitization-callbacks.php
 *
 * @package     NEOVANTAGE
 * @link        https://pixelspress.com/free-wordpress-theme/
 */

/**
 * Select sanitization callback.
 *
 * - Sanitization: select
 * - Control: select, radio
 *
 * Sanitization callback for 'select' and 'radio' type controls. This callback sanitizes `$input`
 * as a slug, and then validates `$input` against the choices defined for the control.
 *
 * @see sanitize_key()               https://developer.wordpress.org/reference/functions/sanitize_key/
 * @see $wp_customize->get_control() https://developer.wordpress.org/reference/classes/wp_customize_manager/get_control/
 *
 * @param string               $input   Slug to sanitize.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return string Sanitized slug if it is a valid choice; otherwise, the setting default.
 */
function neovantage_sanitize_select( $input, $setting ) {
	// Ensure input is a slug.
	$input = sanitize_key( $input );

	// Get list of choices from the control associated with the setting.
	$choices = $setting->manager->get_control( $setting->id )->choices;

	// If the input is a valid key, return it; otherwise, return the default.
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/**
 * Widget sanitization callback.
 *
 * @param string $value possible values enable/disable.
 * @return string
 */
function neovantage_sanitize_widget_area( $value ) {
	if ( ! in_array( $value, array( 'enable', 'disable' ) ) ) {
		$value = 'disable';
	}
	return $value;
}

/**
 * Checkbox sanitization callback.
 *
 * Sanitization callback for 'checkbox' type controls. This callback sanitizes `$checked`
 * as a boolean value, either TRUE or FALSE.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
function neovantage_sanitize_checkbox( $checked ) {
	// Boolean check.
	return ( ( isset( $checked ) && true === $checked ) ? true : false );
}

/**
 * HTML sanitization callback.
 *
 * - Sanitization: html tag hr
 * - Control: Divider
 *
 * Sanitize content for allowed HTML tags for post content.
 *
 * @see     wp_kses_post() https://developer.wordpress.org/reference/functions/wp_kses_post/
 *
 * @param   string $html HTML to sanitize.
 * @return  string Sanitized HTML.
 */
function neovantage_sanitize_html( $html ) {
	return wp_kses_post( force_balance_tags( $html ) );
}

/**
 * URL sanitization callback.
 *
 * - Sanitization: url
 * - Control: text, url
 *
 * Sanitization callback for 'url' type text inputs. This callback sanitizes `$url` as a valid URL.
 *
 * NOTE: esc_url_raw() can be passed directly as `$wp_customize->add_setting()` 'sanitize_callback'.
 * It is wrapped in a callback here merely for example purposes.
 *
 * @see esc_url_raw() https://developer.wordpress.org/reference/functions/esc_url_raw/
 *
 * @param string $url URL to sanitize.
 * @return string Sanitized URL.
 */
function neovantage_sanitize_url( $url ) {
	return esc_url_raw( $url );
}

/**
 * Sanitizes a hex color.
 * Returns either ”, a 3 or 6 digit hex color (with #), or nothing.
 *
 * @since 1.2
 *
 * @param string $color Hex color value.
 * @return string
 */
function neovantage_sanitize_hex_color( $color ) {
	if ( '' === $color ) {
		return '';
	}

	// 3 or 6 hex digits, or the empty string.
	if ( preg_match( '|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
		return $color;
	}
}

/**
 * HTML sanitization callback.
 *
 * - Sanitization: html
 * - Control: text, textarea
 *
 * Sanitization callback for 'html' type text inputs. This callback sanitizes `$html`
 * for HTML allowable in posts.
 *
 * @see wp_filter_post_kses() https://developer.wordpress.org/reference/functions/wp_filter_post_kses/
 *
 * @param string $html HTML to sanitize.
 * @return string Sanitized HTML.
 */
function neovantage_sanitize_none( $html ) {
	return $html;
}

if ( ! function_exists( 'neovantage_switch_sanitization' ) ) {
	/**
	 * Switch sanitization
	 *
	 * @param string $input Switch value.
	 * @version 1.0.0
	 * @since   1.2.6
	 * @return  integer     Sanitized value
	 */
	function neovantage_switch_sanitization( $input ) {
		if ( true === $input ) {
			return 1;
		} else {
			return '';
		}
	}
}

if ( ! function_exists( 'neovantage_text_sanitization' ) ) {
	/**
	 * Text sanitization
	 *
	 * @param  string $input Input to be sanitized (either a string containing a single string or multiple, separated by commas).
	 *
	 * @version 1.0.0
	 * @since   1.2.6
	 * @return  string  Sanitized input
	 */
	function neovantage_text_sanitization( $input ) {
		if ( strpos( $input, ',' ) !== false ) {
			$input = explode( ',', $input );
		}
		if ( is_array( $input ) ) {
			foreach ( $input as $key => $value ) {
				$input[ $key ] = sanitize_text_field( $value );
			}
			$input = implode( ',', $input );
		} else {
			$input = sanitize_text_field( $input );
		}
		return $input;
	}
}

/**
 * No-HTML sanitization callback example.
 *
 * - Sanitization: nohtml
 * - Control: text, textarea, password
 *
 * Sanitization callback for 'nohtml' type text inputs. This callback sanitizes `$nohtml`
 * to remove all HTML.
 *
 * NOTE: wp_filter_nohtml_kses() can be passed directly as `$wp_customize->add_setting()`
 * 'sanitize_callback'. It is wrapped in a callback here merely for example purposes.
 *
 * @see wp_filter_nohtml_kses() https://developer.wordpress.org/reference/functions/wp_filter_nohtml_kses/
 *
 * @param string|string $nohtml The no-HTML content to sanitize.
 * @return string Sanitized no-HTML content.
 */
function neovantage_sanitize_nohtml( $nohtml ) {
	return wp_filter_nohtml_kses( $nohtml );
}

/**
 * Array sanitization callback example.
 *
 * - Sanitization: array
 * - Control: select
 *
 * Sanitization callback for 'array' type select box.
 *
 * @param array $array The array to sanitize.
 * @return array Sanitized array.
 */
function neovantage_sanitize_array( $array ) {

	if ( ! is_array( $array ) ) {
		return array();
	}

	foreach ( $array as $key => $value ) {

		if ( is_array( $value ) ) {
			$array[ $key ] = neovantage_sanitize_array( $value );
		} else {
			$array[ $key ] = esc_attr( $value );
		}
	}

	return $array;
}
