<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package NEOVANTAGE
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function neovantage_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of no-sidebar to sites without active sidebar.
	if ( ! is_active_sidebar( 'sidebar-1' ) ) {
		$classes[] = 'no-sidebar';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	return $classes;
}
add_filter( 'body_class', 'neovantage_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function neovantage_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'neovantage_pingback_header' );

if ( ! function_exists( 'neovantage_maintenance_mode' ) ) :
	/**
	 * Maintenance Mode
	 */
	function neovantage_maintenance_mode() {
		$logo_img       = '';
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		if ( isset( $custom_logo_id ) && ! empty( $custom_logo_id ) ) {
			$image     = wp_get_attachment_image_src( $custom_logo_id, 'full' );
			$logo_path = $image[0];
			if ( isset( $logo_path ) && ! empty( $logo_path ) ) :
				$logo_img = '<img src="' . esc_url( $logo_path ) . '" alt="' . esc_attr__( 'Maintenance', 'neovantage' ) . '" style="margin: 0 auto; display: block;" />';
			endif;
		}
		$neovantage_maintenance_mode_setting = neovantage_get_theme_mod( 'neovantage_maintenance_mode_setting' );

		if ( ! empty( $neovantage_maintenance_mode_setting ) && 1 === $neovantage_maintenance_mode_setting ) {
			if ( ! current_user_can( 'edit_themes' ) || ! is_user_logged_in() ) {
				$maintenance_msg = $logo_img . '<div style="text-align:center">' . neovantage_get_theme_mod( 'neovantage_maintenance_msg_setting' ) . '</div>';
				wp_die( wp_kses_post( $maintenance_msg ), wp_kses_post( get_bloginfo( 'name' ) ) );
			}
		}
	}
endif;
add_action( 'get_header', 'neovantage_maintenance_mode' );

if ( ! function_exists( 'neovantage_add_opengraph_doctype' ) ) :
	/**
	 * Added Open Graph in the Language Attributes
	 *
	 * @param string $output Contains html content.
	 * @since 1.1.1
	 *
	 * @return string
	 */
	function neovantage_add_opengraph_doctype( $output ) {
		return $output . ' xmlns:og="http://opengraphprotocol.org/schema/" xmlns:fb="http://www.facebook.com/2008/fbml"';
	}
endif;
add_filter( 'language_attributes', 'neovantage_add_opengraph_doctype' );

if ( ! function_exists( 'neovantage_social_meta' ) ) :
	/**
	 * Added Social Meta
	 *
	 * @global object $post Global post object.
	 * @since 1.1.1
	 */
	function neovantage_social_meta() {
		global $post;
		$logo_path      = '';
		$custom_logo_id = get_theme_mod( 'custom_logo' );
		if ( isset( $custom_logo_id ) && ! empty( $custom_logo_id ) ) {
			$image     = wp_get_attachment_image_src( $custom_logo_id, 'full' );
			$logo_path = $image[0];
		}

		$themes = wp_get_themes();

		// If we are on a blog post/page.
		if ( is_singular() ) {
			?>
			<meta property="og:title" content="<?php the_title(); ?>">
			<meta property="og:type" content="article">
			<meta property="og:url" content="<?php the_permalink(); ?>">
			<meta property="og:site_name" content="<?php bloginfo( 'name' ); ?>">
			<?php if ( has_excerpt( $post->ID ) ) { ?>
				<meta property="og:description" content="<?php the_excerpt(); ?>">
			<?php } else { ?>
				<meta property="og:description" content="<?php bloginfo( 'description' ); ?>">
			<?php } ?>

			<?php
			if ( has_post_thumbnail( $post->ID ) ) {
				$thumb   = get_post_thumbnail_id();
				$img_url = wp_get_attachment_image_src( $thumb, 'full' );
				$img_url = $img_url[0];
			} else {
				$img_url = $logo_path;
			}
			?>
			<meta property="og:image" content="<?php echo esc_url( $img_url ); ?>">
		<?php } elseif ( is_front_page() || is_home() ) { ?>
			<meta property="og:title" content="<?php bloginfo( 'name' ); ?>">
			<meta property="og:type" content="website">
			<meta property="og:url" content="<?php the_permalink(); ?>">
			<meta property="og:site_name" content="<?php bloginfo( 'name' ); ?>">

			<?php if ( has_excerpt( $post ) ) { ?>
				<meta property="og:description" content="<?php the_excerpt(); ?>">
			<?php } else { ?>
				<meta property="og:description" content="<?php bloginfo( 'description' ); ?>">
			<?php } ?>

			<?php
			if ( has_post_thumbnail( $post ) ) {
				$thumb   = get_post_thumbnail_id();
				$img_url = wp_get_attachment_image_src( $thumb, 'full' );
				$img_url = $img_url[0];
			} else {
				$img_url = $logo_path;
			}
			?>
			<meta property="og:image" content="<?php echo esc_url( $img_url ); ?>">
			<?php
		}
	}
endif;
add_filter( 'wp_head', 'neovantage_social_meta', 2 );

if ( ! function_exists( 'neovantage_excerpt_length' ) ) :
	/**
	 * Filter the except length to 20 words.
	 *
	 * @since 1.1.0
	 *
	 * @param int $length Excerpt length.
	 * @return int (Maybe) modified excerpt length.
	 */
	function neovantage_excerpt_length( $length ) {
		return 35;
	}

endif;
add_filter( 'excerpt_length', 'neovantage_excerpt_length', 999 );

if ( ! function_exists( 'neovantage_excerpt_more' ) ) :
	/**
	 * Filter the excerpt "read more" string.
	 *
	 * @since 1.1.0
	 *
	 * @param string $more "Read more" excerpt string.
	 * @return string (Maybe) modified "read more" excerpt string.
	 */
	function neovantage_excerpt_more( $more ) {
		return ' ...';
	}

endif;
add_filter( 'excerpt_more', 'neovantage_excerpt_more' );

if ( ! function_exists( 'neovantage_custom_html_code_head' ) ) :
	/**
	 * Filter wp_head to add custom HTML code in head
	 *
	 * @since 1.2
	 *
	 * @return void.
	 */
	function neovantage_custom_html_code_head() {
		$neovantage_code_head = neovantage_get_theme_mod( 'neovantage_code_head', false );
		if ( ! empty( $neovantage_code_head ) ) :
			echo $neovantage_code_head;  // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		endif;
	}

endif;
add_filter( 'wp_head', 'neovantage_custom_html_code_head' );

if ( ! function_exists( 'neovantage_custom_styles' ) ) :
	/**
	 * Change Primary Colour
	 */
	function neovantage_custom_styles() {
		$theme_color     = neovantage_get_theme_mod( 'neovantage_theme_color' );
		$header_bg_color = neovantage_get_theme_mod( 'neovantage_header_bg_color' );
		?>
		<style type="text/css">
		<?php if ( $theme_color ) : ?>
				a:hover, a:focus { color: <?php echo esc_attr( $theme_color ); ?>; }

				.pagination > li > a:hover, .pagination > li > span:hover, .pagination > li > a:focus, .pagination > li > span:focus {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.pagination > .active > a, .pagination > .active > span, .pagination > .active > a:hover, .pagination > .active > span:hover, .pagination > .active > a:focus, .pagination > .active > span:focus {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.label-primary {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.list-group-item.active,
				.list-group-item.active:hover,
				.list-group-item.active:focus {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				#featured {
					background: <?php echo esc_attr( $theme_color ); ?>;
				}
				article.entry-header h2 a,.btn-primary .badge,.btn-link:hover,.btn-link:focus {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				## Core -> Typography
				------------------------------------------------------------------*/
				h1,h2,h3,h4,h5,h6,.h1,.h2,.h3,.h4,.h5,.h6 {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.text-primary { color: <?php echo esc_attr( $theme_color ); ?>; }
				.bg-primary { color: <?php echo esc_attr( $theme_color ); ?>; }

				/*------------------------------------------------------------------
				## Block -> Paragraph
				------------------------------------------------------------------*/
				.has-drop-cap:not(:focus):first-letter {
					background: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------------------
				### Components -> Buttons -> Alternates
				------------------------------------------------------------------------------*/
				.btn-primary {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.btn.btn-primary:hover, .btn.btn-primary:focus, .btn.btn-primary:active, .btn.btn-primary::after {
					background-color: <?php echo esc_attr( neovantage_adjust_brightness( $theme_color, -20 ) ); ?>;
					border-color: <?php echo esc_attr( neovantage_adjust_brightness( $theme_color, -20 ) ); ?>;
				}

				.btn-primary.disabled:hover, .btn-primary[disabled]:hover, fieldset[disabled] .btn-primary:hover, .btn-primary.disabled:focus, .btn-primary[disabled]:focus, fieldset[disabled] .btn-primary:focus, .btn-primary.disabled.focus, .btn-primary[disabled].focus, fieldset[disabled] .btn-primary.focus {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.btn-primary .badge { color: <?php echo esc_attr( $theme_color ); ?>; }
				.btn-link:hover,.btn-link:focus { color: <?php echo esc_attr( $theme_color ); ?>; }
				/*------------------------------------------------------------------
				#### Components -> Forms -> Form Control -> Common
				------------------------------------------------------------------*/
				.form-control:focus {
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				## Components -> WP Comments -> Base
				------------------------------------------------------------------*/
				.comments-area .comments-title > span:before, .comments-area .comment-reply-title > span:before {
					border-right-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Components > Widgets
				------------------------------------------------------------------*/
				.widget .widget-title > span::before {
					border-right-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.widget select:focus { border-color: <?php echo esc_attr( $theme_color ); ?>; }
				#secondary .widget .widget-title a { color: <?php echo esc_attr( $theme_color ); ?>; }
				.widget.widget_tag_cloud .tagcloud a:hover {
					background: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( neovantage_adjust_brightness( $theme_color, -20 ) ); ?>;
				}
				/*------------------------------------------------------------------
				## Components > Page Header
				------------------------------------------------------------------*/
				.page-header .pre-page-title span:before {
					border-right-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				# Components -> Blockquotes
				------------------------------------------------------------------*/
				blockquote, blockquote.wp-block-quote {
					border-left-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.blockquote-reverse, blockquote.pull-right {
					border-right-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				# Blog - Article
				------------------------------------------------------------------*/
				article .entry-header .entry-title a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Components > Addon Group
				------------------------------------------------------------------*/
				.input-group-addon {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.input-group-addon .btn-default {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.input-group-addon .btn-default:hover, .input-group-addon .btn-default:focus {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
					border-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Blog > Post Meta
				------------------------------------------------------------------*/
				.entry-categories li a {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Blog > Article
				------------------------------------------------------------------*/
				article .entry-header h2 a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Components > Entry Content Link
				------------------------------------------------------------------*/
				.single .entry-content a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Components > Pagination
				------------------------------------------------------------------*/
				.navigation.pagination .nav-links .current {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				#pagination .neovantage-empty:hover {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.navigation.post-navigation .nav-links a:hover, .navigation.post-navigation .nav-links a:focus {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Blog > Article
				------------------------------------------------------------------*/
				article .entry-header h2 a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.single .entry-content a:not(.carousel-control) {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Breadcrumb
				------------------------------------------------------------------*/
				.breadcrumb > li a:hover, .breadcrumb > li a:focus {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.knowledge-base .site-header-search {
					background-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				## Components -> Newsticker -> Base
				------------------------------------------------------------------*/
				.neovantage-newsticker-wrapper .neovantage-newsticker .heading {
					background: <?php echo esc_attr( $theme_color ); ?>;
				}
				.neovantage-newsticker-wrapper .neovantage-newsticker .control-nav span {
					background: <?php echo esc_attr( $theme_color ); ?>;
				}
				.neovantage-newsticker-wrapper .neovantage-newsticker .heading:after {
					border-left-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------------------
				## Blog - Post Meta
				------------------------------------------------------------------------------*/
				.entry-terms .tags-links a:hover,
				.entry-terms .tags-links a:active,
				.entry-terms .tags-links a:focus {
					background: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * Blog > Related Post
				------------------------------------------------------------------*/
				.related-post-title > span::before,
				.related-post .related-post-title > span::before {
					border-right-color: <?php echo esc_attr( $theme_color ); ?>;
				}
				.related-post .neovantage-blog-box .iq-blog-detail .entry-title a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}
				/*------------------------------------------------------------------
				 * NEO Bootstrap Carousel
				------------------------------------------------------------------*/
				.nkb-category .nkb-category-article-list a {
					color: <?php echo esc_attr( $theme_color ); ?>;
				}

				.nkb-category .nkb-category-article-list a:hover,
				.nkb-category .nkb-category-article-list a:active,
				.nkb-category .nkb-category-article-list a:focus {
					color: <?php echo esc_attr( neovantage_adjust_brightness( $theme_color, -20 ) ); ?>;
				}
		<?php endif; ?>

		<?php if ( $header_bg_color ) : ?>
				/*------------------------------------------------------------------
				## Header -> Background Color
				------------------------------------------------------------------*/
				.site-header {
					background-color: <?php echo esc_attr( $header_bg_color ); ?>;
				}
		<?php endif; ?>
		</style>
		<?php
	}

endif;
add_action( 'wp_head', 'neovantage_custom_styles', 100 );

if ( ! function_exists( 'neovantage_cookie_consent' ) ) :
	/**
	 * Cookie Consent Warning Strap
	 *
	 * @access     public
	 * @version    1.0.0
	 * @since      1.2.6
	 */
	function neovantage_cookie_consent() {
		$neovantage_notifications_status = neovantage_get_theme_mod( 'neovantage_notifications' );
		if ( $neovantage_notifications_status ) :
			?>
			<div <?php neovantage_customizer_hidden_attr( 'neovantage_notifications' ); ?>>
				<div id="cookie-consent">
			<?php echo wp_kses_post( neovantage_get_theme_mod( 'neovantage_notifications_text' ) ); ?>

			<?php if ( neovantage_get_theme_mod( 'neovantage_notifications_more_info_page' ) ) : ?>
					<a href="<?php echo esc_url( get_permalink( '' . neovantage_get_theme_mod( 'neovantage_notifications_more_info_page' ) . '' ) ); ?>" target="_blank" class="more-info"><?php echo esc_html( neovantage_get_theme_mod( 'neovantage_notifications_more_info_text' ) ); ?></a>
			<?php elseif ( get_option( 'wp_page_for_privacy_policy' ) ) : ?>
					<a href="<?php echo esc_url( get_permalink( '' . get_option( 'wp_page_for_privacy_policy' ) . '' ) ); ?>" target="_blank" class="more-info"><?php esc_html_e( 'Privacy Policy', 'neovantage' ); ?></a>
			<?php endif; ?>
					<a class="btn btn-primary btn-cookie-consent-ok"><?php echo esc_html( neovantage_get_theme_mod( 'neovantage_notifications_accept_button_text' ) ); ?></a>
				</div>
				<script type="text/javascript">
					;
					(function ($) {
						"use strict";

						function neovantageReadCookie(cookieName) {
							var theCookie = " " + document.cookie;
							var ind = theCookie.indexOf(" " + cookieName + "=");
							if (ind == -1)
								ind = theCookie.indexOf(";" + cookieName + "=");
							if (ind == -1 || cookieName == "")
								return "";
							var ind1 = theCookie.indexOf(";", ind + 1);
							if (ind1 == -1)
								ind1 = theCookie.length;

							// Returns true if the versions match
							return cc_vars.version == unescape(theCookie.substring(ind + cookieName.length + 2, ind1));
						}
						function neovantageDeleteCookie(cookieName) {
							document.cookie = cookieName + '=;expires=Thu, 01 Jan 1970 00:00:01 GMT;path=/';
						}

						$(document).ready(function () {
							if ($('#cookie-consent').length) {
								<?php if ( isset( $_GET['cookie'] ) ) { ?>
									neovantageDeleteCookie('neovantageCookiesConsent');
								<?php } ?>
								if (!neovantageReadCookie("neovantageCookiesConsent")) { // If the cookie has not been set then show the bar.
									setTimeout(function () {
										$("#cookie-consent").fadeIn(200);
									}, 2000);
								}
							}
						});
					})(jQuery);
				</script>
			</div>
			<?php
		endif;
	}

endif;
add_action( 'wp_footer', 'neovantage_cookie_consent', 1000 );

if ( ! function_exists( 'neovantage_page_header_callback' ) ) :
	/**
	 * Page Header
	 *
	 * @return void
	 */
	function neovantage_page_header_callback() {
		if ( ! is_home() ) {

			global $wp_query;
			$term_id = $wp_query->get_queried_object_id();

			$rss_link = get_category_feed_link( $term_id );
			?>
			<!-- Page Header -->
			<section class="page-header">

				<!-- Page Headers -->
				<?php
				if ( is_category() ) {
					$pre_title = esc_html__( 'Browsing Category', 'neovantage' );
				} elseif ( is_tag() ) {
					$pre_title = esc_html__( 'Browsing Tag', 'neovantage' );
				} elseif ( is_author() ) {
					$pre_title = esc_html__( 'Author', 'neovantage' );
				} elseif ( is_date() ) {
					$pre_title = esc_html__( 'Archives', 'neovantage' );
				} elseif ( is_search() ) {
					$pre_title = sprintf(
						/* translators: %s: Search String. */
						esc_html__( 'Search Result For: %s', 'neovantage' ),
						get_search_query()
					);
				} else {
					$pre_title = '';
				}
				?>

				<?php if ( ! empty( $pre_title ) ) : ?>
				<h3 class="pre-page-title">
					<span><?php echo esc_html( $pre_title );  // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></span>
				</h3>
				<?php endif; ?>

			<?php if ( ! empty( $rss_link ) ) { ?>
					<!-- RSS -->
					<div class="actions-container">
						<a class="rss-link" href="<?php echo esc_url( $rss_link ); ?>"><i class="icon lynny-web-rss-1"></i></a>
					</div>
			<?php } ?>

				<!-- Page Title -->
			<?php if ( is_archive() && ( is_category() || is_tag() ) ) { ?>
				<?php the_archive_title( '<h1 class="page-title"><span>', '</span></h1>' ); ?>
				<?php the_archive_description( '<div class="taxonomy-description">', '</div>' ); ?>
			<?php } elseif ( is_archive() && is_author() ) { ?>
				<?php get_template_part( 'template-parts/author-box' ); ?>
			<?php } ?>


			</section>
			<?php
		}
	}

endif;
add_action( 'neovantage_page_header', 'neovantage_page_header_callback' );

if ( ! function_exists( 'neovantage_single_header_callback' ) ) :
	/**
	 * Single Page Header
	 *
	 * @return void
	 */
	function neovantage_single_header_callback() {

		$page_header_class = 'page-header';
		$page_header_bg    = '';
		$src               = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'blog-large', false, '' );
		if ( $src[0] ) :
			$page_header_class = 'page-header-with-bg';
			$page_header_bg    = 'style="background-image: url(' . esc_url( $src[0] ) . ');"';
		endif;

		$neovantage_get_image_from_content = neovantage_get_theme_mod( 'neovantage_get_image_from_content' );
		if ( ! $src[0] && $neovantage_get_image_from_content ) :

			global $post;
			$output = preg_match_all( '|<img.*?src=[\'"](.*?)[\'"].*?>|i', $post->post_content, $matches );
			if ( isset( $matches[1][0] ) ) :
				$page_header_class = 'page-header-with-bg';
				$page_header_bg    = 'style="background-image: url(' . esc_url( $matches[1][0] ) . ');"';
			endif;
		endif;
		?>
		<!-- Page Header -->
		<section class="page-header">
			<!-- Breadcrumb -->
		<?php echo wp_kses_post( neovantage_breadcrumbs() ); ?>
		</section>
		<?php
	}

endif;
add_action( 'neovantage_single_header', 'neovantage_single_header_callback' );

if ( ! function_exists( 'neovantage_get_the_archive_title' ) ) :

	/**
	 * Modify the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 *
	 * @return string
	 */
	function neovantage_get_the_archive_title( $title ) {

		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_author() ) {
			$title = get_the_author();
		}

		return $title;
	}

endif;
add_filter( 'get_the_archive_title', 'neovantage_get_the_archive_title' );

/**
 * Exclude Page post type from global search
 *
 * @param array  $args Array of arguments for registering a post type.
 * @param string $name Post type key.
 *
 * @return array
 */
function neovantage_page_search_filter( $args, $name ) {

	if ( 'page' === $name ) {
		$args['exclude_from_search'] = true;
	}

	return $args;
}
add_filter( 'register_post_type_args', 'neovantage_page_search_filter', 10, 2 );

/**
 * Configuration for NEOVANTAGE Breadcrumb
 *
 * @hooked neovantage_breadcrumb_options
 *
 * @param array $options Breadcrumb option array.
 *
 * @return array
 */
function neovantage_breadcrumb_config( $options ) {

	$options['labels'] = array(
		'aria_label'          => 'Breadcrumbs',
		'home'                => 'Home',
		'error_404'           => '404 Not Found',
		'archives'            => 'Archives',
		'search'              => 'Search results for "%s"',
		'paged'               => 'Page %s',
		'archive_minute'      => 'Minute %s',
		'archive_week'        => 'Week %s',
		'archive_minute_hour' => '%s',
		'archive_hour'        => '%s',
		'archive_day'         => '%s',
		'archive_month'       => '%s',
		'archive_year'        => '%s',
	);

	$options['show_date_in_post'] = '';

	$taxonomies = array();

	if ( neovantage_taxonomy_supports_post_type( 'category', 'post' ) ) {
		$taxonomies['post'] = 'category';
	}

	if ( neovantage_taxonomy_supports_post_type( 'category', 'page' ) ) {
		$taxonomies['page'] = 'category';
	}

	$options['post_taxonomy'] = $taxonomies;
	unset( $taxonomies );

	return $options;
}
// Breadcrumb config.
add_filter( 'neovantage_breadcrumb_options', 'neovantage_breadcrumb_config', 100 );

/**
 * Callback: Used for changing WP_Query, specifically for posts per page in archives
 *
 * @param   WP_Query $query WP_Query instance.
 */
function neovantage_pre_get_posts( $query ) {

	// This is only for front end and main query.
	if ( is_admin() || ! $query->is_main_query() ) {
		return;
	}

	//
	// Cache the queried_object and queried_object_id values to return back them at the end of function
	// because when we call the $query->get_queried_object() it will cache the value in the WP_Query
	// but it's so soon to cache it and it will be changed after "pre_get_posts".
	// we will returns this values at the end.
	// There is no need to do this but i added to make sure there will not be any issue!
	//
	{
		$_queried_object    = $query->queried_object;
		$_queried_object_id = $query->queried_object_id;
	}

	// Posts per page for categories.
	if ( $query->get_queried_object_id() > 0 && neovantage_is_valid_tax( 'category', $query->get_queried_object() ) ) {

		$offset = 4;
		$paged  = get_query_var( 'paged' );
		$limit  = get_option( 'posts_per_page' );
		$query->set( 'posts_per_page', $limit );

		// exclude first.
		if ( $paged > 1 ) {
			$query->set( 'offset', $offset + ( ( $paged - 1 ) * $limit ) );
			$query->set( 'original_offset', $offset );
		} else {
			$query->set( 'offset', $offset );
		}
	}

	// Return back the data that cached at first.
	{
		$query->queried_object = $_queried_object;
		unset( $_queried_object );
		$query->queried_object_id = $_queried_object_id;
		unset( $_queried_object_id );
	}
}
// pre_get_posts hook.
add_action( 'pre_get_posts', 'neovantage_pre_get_posts', 1 );

/**
 * Using the found_posts filter to correct the pagination problem
 *
 * @param int    $found_posts The number of posts found.
 * @param object $query (WP_Query) The WP_Query instance (passed by reference).
 * @return int
 */
function neovantage_adjust_offset_pagination( $found_posts, $query ) {

	// Define our offset again...
	$offset = 4;

	// Ensure we're modifying the right query object...
	if ( $query->get_queried_object_id() > 0 && neovantage_is_valid_tax( 'category', $query->get_queried_object() ) ) {
		// Reduce WordPress's found_posts count by the offset...
		return $found_posts - $offset;
	}
	return $found_posts;
}
// found_posts hook.
add_filter( 'found_posts', 'neovantage_adjust_offset_pagination', 1, 2 );


if ( ! function_exists( 'neovantage_widget_categories_post_count_filter' ) ) {

	/**
	 * Used to wrap archives count inside span
	 *
	 * @param mixed $links links found in content.
	 *
	 * @return mixed
	 */
	function neovantage_widget_categories_post_count_filter( $links ) {

		$links = str_replace( '</a> (', '</a><span>', trim( $links ) );
		$links = str_replace( ')', '</span>', $links );
		return $links;
	}
}
// Hook to wp_list_categories.
add_filter( 'wp_list_categories', 'neovantage_widget_categories_post_count_filter' );

if ( ! function_exists( 'neovantage_widget_archive_post_count_filter' ) ) {

	/**
	 * Used to wrap archives count inside span
	 *
	 * @param mixed $links Links found in content.
	 *
	 * @return mixed
	 */
	function neovantage_widget_archive_post_count_filter( $links ) {

		$links = str_replace( '</a>&nbsp;(', '</a><span>', trim( $links ) );
		$links = str_replace( ')', '</span>', $links );
		return $links;
	}
}
// Hook to get_archives_link.
add_filter( 'get_archives_link', 'neovantage_widget_archive_post_count_filter' );

/**
 * Add preconnect for Google Fonts.
 *
 * @param  array|array   $urls           URLs to print for resource hints.
 * @param  string|string $relation_type  The relation type the URLs are printed.
 * @return array|array   $urls           URLs to print for resource hints.
 */
function neovantage_resource_hints( $urls, $relation_type ) {

	if ( wp_style_is( 'neovantage-google-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => '//fonts.gstatic.com',
			'crossorigin',
		);
	}

	return $urls;
}

add_filter( 'wp_resource_hints', 'neovantage_resource_hints', 10, 2 );

/**
 * Flush out the transients used in neovantage_categorized_blog.
 */
function neovantage_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}

	// Like, beat it. Dig?
	delete_transient( 'neovantage_categories' );
}
add_action( 'edit_category', 'neovantage_category_transient_flusher' );
add_action( 'save_post', 'neovantage_category_transient_flusher' );
